summaryrefslogtreecommitdiffstats
path: root/kmail/kmheaders.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmheaders.h')
-rw-r--r--kmail/kmheaders.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/kmail/kmheaders.h b/kmail/kmheaders.h
index 4eddbdf4..e6bbe422 100644
--- a/kmail/kmheaders.h
+++ b/kmail/kmheaders.h
@@ -10,7 +10,7 @@ using KMail::HeaderItem;
#include <klistview.h>
#include <kfoldertree.h> // for KPaintInfo
-#include <kmmsgbase.h> // for KMMsgStatus
+#include <kmmsgbase.h> // for KMMsgtqStatus
#include <tqwidget.h>
#include <tqstrlist.h>
@@ -48,11 +48,12 @@ enum NestingPolicy { AlwaysOpen = 0, DefaultOpen, DefaultClosed, OpenUnread };
class KMHeaders : public KListView
{
Q_OBJECT
+ TQ_OBJECT
friend class ::KMail::HeaderItem; // For easy access to the pixmaps
public:
- KMHeaders(KMMainWidget *owner, TQWidget *parent=0, const char *name=0);
+ KMHeaders(KMMainWidget *owner, TQWidget *tqparent=0, const char *name=0);
virtual ~KMHeaders();
/** A new folder has been selected update the list of headers shown
@@ -76,13 +77,13 @@ public:
/** Set all messages in the current thread to status @p status
or toggle it, if specified. */
- virtual void setThreadStatus(KMMsgStatus status, bool toggle=false);
+ virtual void setThreadtqStatus(KMMsgtqStatus status, bool toggle=false);
/* Set message status to read if it is new, or unread */
virtual void setMsgRead(int msgId);
/** The following methods processes all selected messages. */
- virtual void setMsgStatus(KMMsgStatus status, bool toggle=false);
+ virtual void setMsgtqStatus(KMMsgtqStatus status, bool toggle=false);
virtual void deleteMsg();
virtual void applyFiltersOnMsg();
virtual void undo();
@@ -113,7 +114,7 @@ public:
/** Returns the sernums of all selected items. */
TQValueList<TQ_UINT32> selectedSernums();
/** Returns the sernums of all visible (ie. items with expanded parent, not hidden by
eg. the quick search) selected items.
*/
TQValueList<TQ_UINT32> selectedVisibleSernums();
@@ -284,13 +285,13 @@ public slots:
virtual void ensureCurrentItemVisible();
- /** Select an item and if it is the parent of a closed thread, also
- recursively select its children. */
+ /** Select an item and if it is the tqparent of a closed thread, also
+ recursively select its tqchildren. */
virtual void setSelected(TQListViewItem *item, bool selected);
/** Select several items by message index
* and if they are the parent of a closed thread, also
* recursively select their children. */
void setSelectedByIndex(TQValueList<int> items, bool selected);
/** switch a column with the given id (see KPaintInfo enum)
@@ -298,7 +299,7 @@ public slots:
void slotToggleColumn(int id, int mode = -1);
/** Provide information about number of messages in a folder */
- void setFolderInfoStatus();
+ void setFolderInfotqStatus();
protected:
static TQPixmap *pixNew, *pixUns, *pixDel, *pixRead, *pixRep, *pixSent,
@@ -113,7 +114,7 @@ public:
/** Returns the sernums of all selected items. */
TQValueList<TQ_UINT32> selectedSernums();
- /** Returns the sernums of all visible (ie. items with expanded parent, not hidden by
+ /** Returns the sernums of all visible (ie. items with expanded tqparent, not hidden by
eg. the quick search) selected items.
*/
@@ -284,13 +285,13 @@ public slots:
virtual void setSelected(TQListViewItem *item, bool selected);
/** Select several items by message index
- * and if they are the parent of a closed thread, also
- * recursively select their children. */
+ * and if they are the tqparent of a closed thread, also
+ * recursively select their tqchildren. */
void setSelectedByIndex(TQValueList<int> items, bool selected);
/** switch a column with the given id (see KPaintInfo enum)